@@ -3,8 +3,7 @@ use futures::prelude::*;
 pub use libpacket::*;
 use netsim_embed_core::*;
 pub use netsim_embed_core::{DelayBuffer, Ipv4Range};
-use netsim_embed_machine::*;
-pub use netsim_embed_machine::{unshare_user, MachineId, Namespace};
+pub use netsim_embed_machine::{unshare_user, Machine, MachineId, Namespace};
 use netsim_embed_nat::*;
 use netsim_embed_router::*;
 use std::fmt::Display;
